Span

Enum Span 

pub enum Span {
    Parsed(ParsedSpan),
    DuplicateRecordFieldsSugar(Box<Span>, Box<Span>),
    DottedFieldSugar,
    RecordPunSugar,
    Decoded,
    Artificial,
}

Variants



Parsed(ParsedSpan)

A location in the source text



DuplicateRecordFieldsSugar(Box<Span>, Box<Span>)

Desugarings



DottedFieldSugar



RecordPunSugar



Decoded

For expressions obtained from decoding binary



Artificial

For expressions constructed during normalization/typecheck

Implementations

Source

impl Span

pub fn make(input: Rc<str>, sp: Span<'_>) -> Self

pub fn union(&self, other: &Span) -> Self

Takes the union of the two spans, i.e. the range of input covered by the two spans plus any input between them. Assumes that the spans come from the same input. Fails if one of the spans does not point to an input location.